diff --git wp-includes/comment-template.php wp-includes/comment-template.php
index e6b246c..5c6c7c3 100644
--- wp-includes/comment-template.php
+++ wp-includes/comment-template.php
@@ -1032,15 +1032,17 @@ function comment_text( $comment_ID = 0, $args = array() ) {
  * Retrieves the comment time of the current comment.
  *
  * @since 1.5.0
+ * @since 4.4.0 Added the ability for `$comment_ID` to also accept a WP_Comment object.
  *
  * @param string $format    Optional. PHP date format. Defaults to the 'time_format' option.
  * @param bool   $gmt       Optional. Whether to use the GMT date. Default false.
  * @param bool   $translate Optional. Whether to translate the time (for use in feeds).
  *                          Default true.
  * @return string The formatted time.
  */
-function get_comment_time( $format = '', $gmt = false, $translate = true ) {
-	$comment = get_comment();
+function get_comment_time( $format = '', $gmt = false, $translate = true, $comment_ID = 0 ) {
+	$comment = get_comment( $comment_ID );
 
 	$comment_date = $gmt ? $comment->comment_date_gmt : $comment->comment_date;
 
@@ -1032,15 +1032,17 @@ function comment_text( $comment_ID = 0, $args = array() ) {
  *
- * @param string $format    Optional. PHP date format. Defaults to the 'time_format' option.
- * @param bool   $gmt       Optional. Whether to use the GMT date. Default false.
- * @param bool   $translate Optional. Whether to translate the time (for use in feeds).
- *                          Default true.
+ * @param string         $format     Optional. PHP date format. Defaults to the 'time_format' option.
+ * @param bool           $gmt        Optional. Whether to use the GMT date. Default false.
+ * @param bool           $translate  Optional. Whether to translate the time (for use in feeds).
+ *                                   Default true.
+ * @param int|WP_Comment $comment_ID WP_Comment or ID of the comment for which to get the date.
  * @return string The formatted time.
  */
